@@ -1,11 +1,15 @@
 """Parses a URL using the publicsuffix.org TLD list."""
 
 try:
+    python_version = ''
     import cPickle as pickle
-except:
+    from urllib2 import urlopen
+    from urlparse import urlparse
+except ImportError:
+    python_version = '3'
     import pickle
-import urllib2
-from urlparse import urlparse
+    from urllib.request import urlopen
+    from urllib.parse import urlparse
 
 TLD_URL = 'https://publicsuffix.org/list/effective_tld_names.dat'
 
@@ -13,29 +17,26 @@ def get_tlds():
     """Return a list of top-level domains as maintained by Mozilla and
     publicsuffix.org."""
     try:
-        with open('.tlds.pickle') as infile:
-            return pickle.load(infile)
+        with open('.tlds{}.pickle'.format(python_version), 'rb') as infile:
+           return pickle.load(infile)
     except IOError:
         pass
-
-    response = urllib2.urlopen(TLD_URL)
-
-    if response.code != 200:
-        raise RuntimeError('Unable to get list of TLDs')
+    try:
+        response = urlopen(TLD_URL).read().decode('utf-8').split('\n')
+    except Exception as err:
+        raise err
     tlds = {'starred': [], 'normal': []}
-    for line in response.readlines()[1:]:
-        if line.startswith('//') or line == '\n':
+    for line in response:
+        if line.startswith('//') or line in ['\n', '']:
             continue
         if line.startswith('*'):
             tlds['starred'].append(line.strip())
         else:
             tlds['normal'].append(line.strip())
 
-    with open('.tlds.pickle', 'w') as outfile:
+    with open('.tlds{}.pickle'.format(python_version), 'wb') as outfile:
         pickle.dump(tlds, outfile)
 
-    import pprint
-    pprint.pprint(tlds)
     return tlds
 
 def parse_domain(url):
@@ -47,11 +48,12 @@ def parse_domain(url):
     unrecognizable TLD, assumes it is one level.
     """
 
-    if not url.startswith('http://'):
+    if not (url.startswith('http://') or url.startswith('https://')):
         url = 'http://' + url
     top_level_domains = get_tlds()
     parsed = urlparse(url.lower())
-    hostname = parsed.netloc
+    hostname = (parsed.netloc if python_version else 
+        parsed.netloc.decode('utf-8'))
 
     tld = ''
     tld_index = 0
@@ -69,4 +71,5 @@ def parse_domain(url):
     second_level_domain = ''.join(uri[tld_index-1:tld_index])
     subdomains = '.'.join(uri[:tld_index-1])
 
-    return tld, second_level_domain, subdomains
+    return tld if python_version else tld.encode('utf-8'),\
+     str(second_level_domain), subdomains
